.. ammico documentation master file, created by
   sphinx-quickstart on Mon Dec 19 13:39:22 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AMMICO's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme_link
   faq_link
   create_API_key_link
   notebooks/DemoNotebook_ammico
   notebooks/Example cropposts
   modules
   license_link

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
